export declare enum FileType {
    Unknown = 0,
    File = 1,
    Directory = 2,
    SymbolicLink = 3
}
export interface UnixPermissions {
    readonly user: number;
    readonly group: number;
    readonly world: number;
}
/**
 * Describes a file, directory or symbolic link. Note that FTP file listings are not standardized. It depends
 * on the operating system of the FTP server how complete the information is.
 */
export declare class FileInfo {
    name: string;
    static UnixPermission: {
        Read: number;
        Write: number;
        Execute: number;
    };
    type: FileType;
    size: number;
    /**
     * Unix permissions if present. If the underlying FTP server is not running on Unix or doesn't report
     * permissions this will be undefined. If set, you might be able to edit permissions with the FTP command `SITE CHMOD`.
     */
    permissions: UnixPermissions | undefined;
    hardLinkCount: number;
    link: string;
    group: string;
    user: string;
    /**
     * Unparsed date as a string. Be careful when trying to parse this by yourself. There is no
     * standard format on which FTP servers agree when using the LIST command. Date information is meant
     * to be human-readable but not necessarily easy to parse. See `modifiedAt` for a parsed date.
     */
    date: string;
    /**
     * Parsed modification date is available (and reliable) if the MLSD command is supported by the FTP server.
     */
    modifiedAt: Date | undefined;
    constructor(name: string);
    readonly isDirectory: boolean;
    readonly isSymbolicLink: boolean;
    readonly isFile: boolean;
}
