"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FileType;
(function (FileType) {
    FileType[FileType["Unknown"] = 0] = "Unknown";
    FileType[FileType["File"] = 1] = "File";
    FileType[FileType["Directory"] = 2] = "Directory";
    FileType[FileType["SymbolicLink"] = 3] = "SymbolicLink";
})(FileType = exports.FileType || (exports.FileType = {}));
/**
 * Describes a file, directory or symbolic link. Note that FTP file listings are not standardized. It depends
 * on the operating system of the FTP server how complete the information is.
 */
class FileInfo {
    constructor(name) {
        this.name = name;
        this.type = FileType.Unknown;
        this.size = 0;
        this.hardLinkCount = 0;
        this.link = "";
        this.group = "";
        this.user = "";
        /**
         * Unparsed date as a string. Be careful when trying to parse this by yourself. There is no
         * standard format on which FTP servers agree when using the LIST command. Date information is meant
         * to be human-readable but not necessarily easy to parse. See `modifiedAt` for a parsed date.
         */
        this.date = "";
        this.name = name;
    }
    get isDirectory() {
        return this.type === FileType.Directory;
    }
    get isSymbolicLink() {
        return this.type === FileType.SymbolicLink;
    }
    get isFile() {
        return this.type === FileType.File;
    }
}
exports.FileInfo = FileInfo;
FileInfo.UnixPermission = {
    Read: 4,
    Write: 2,
    Execute: 1
};
